@@ -1,6 +1,11 @@
 import trimesh
 import fcl
 import logging
+import os
+import sys
+
+if sys.platform != "win32":
+    from wurlitzer import Wurlitzer
 
 from linkmotion.robot.shape.base import ShapeBase
 from linkmotion.transform import Transform
@@ -104,13 +109,32 @@ class MeshShape(ShapeBase):
         Returns:
             An FCLBVH object.
         """
-        bvh = fcl.BVHModel()
-        bvh.beginModel(
-            len(self.collision_mesh.vertices), len(self.collision_mesh.faces)
-        )
-        bvh.addSubModel(self.collision_mesh.vertices, self.collision_mesh.faces)
-        bvh.endModel()
-        return bvh
+        if (
+            len(self.collision_mesh.vertices) == 0
+            or len(self.collision_mesh.faces) == 0
+        ):
+            logger.debug(
+                "Dummy MeshShape with no vertices or faces has been created. "
+                "You should not use this for collision checking."
+            )
+
+        def create_bvh_model():
+            bvh = fcl.BVHModel()
+            bvh.beginModel(
+                len(self.collision_mesh.vertices), len(self.collision_mesh.faces)
+            )
+            bvh.addSubModel(self.collision_mesh.vertices, self.collision_mesh.faces)
+            bvh.endModel()
+            return bvh
+
+        # When Windows ('win32'), Wurlitzer is not used and executed directly
+        if sys.platform == "win32":
+            return create_bvh_model()
+        # On non-Windows, Wurlitzer is used to suppress C library output
+        else:
+            with open(os.devnull, "w") as devnull:
+                with Wurlitzer(stdout=devnull, stderr=devnull):
+                    return create_bvh_model()
 
     def transformed_collision_mesh(
         self, transform: Transform | None = None
