@@ -629,7 +629,7 @@ class UrdfWriter:
                     color=shape.color,
                 )
 
-                logger.info(
+                logger.debug(
                     f"Converted {type(shape).__name__} to mesh geometry: {filename}"
                 )
                 return mesh_shape
@@ -671,9 +671,7 @@ class UrdfWriter:
             return origin_elem
         return None
 
-    def _create_origin_element_from_transform(
-        self, transform: Transform
-    ) -> Optional[ET.Element]:
+    def _create_origin_element_from_transform(self, transform: Transform) -> ET.Element:
         """Create an origin XML element from a Transform object.
 
         Args:
@@ -682,11 +680,14 @@ class UrdfWriter:
         Returns:
             Origin XML element or None if transform is identity.
         """
-        if transform.is_identity():
-            return None
-
         origin_elem = ET.Element("origin")
 
+        # If the transform is identity, return with zero attributes
+        if transform.is_identity():
+            origin_elem.set("rpy", "0 0 0")
+            origin_elem.set("xyz", "0 0 0")
+            return origin_elem
+
         # Add translation
         translation = transform.position
         if not np.allclose(translation, [0, 0, 0]):
@@ -702,7 +703,11 @@ class UrdfWriter:
         # Only return the element if it has attributes
         if origin_elem.attrib:
             return origin_elem
-        return None
+
+        # If no attributes were added, return identity
+        origin_elem.set("rpy", "0 0 0")
+        origin_elem.set("xyz", "0 0 0")
+        return origin_elem
 
     def _create_joint_element(
         self,
@@ -733,9 +738,13 @@ class UrdfWriter:
         # Add origin using the computed relative transform
         if relative_transform is not None and not relative_transform.is_identity():
             origin_elem = self._create_origin_element_from_transform(relative_transform)
-            if origin_elem is not None:
-                joint_elem.append(origin_elem)
-
+            joint_elem.append(origin_elem)
+        else:
+            # If no relative transform, add identity origin
+            origin_elem = ET.Element("origin")
+            origin_elem.set("rpy", "0 0 0")
+            origin_elem.set("xyz", "0 0 0")
+            joint_elem.append(origin_elem)
         # Add axis for non-fixed joints using the computed relative axis
         if joint.type != JointType.FIXED and relative_axis is not None:
             axis_elem = ET.SubElement(joint_elem, "axis")
