@@ -4,7 +4,7 @@ import numpy as np
 from linkmotion.robot.robot import Robot
 from linkmotion.robot.link import Link
 from linkmotion.robot.joint import Joint, JointType
-from linkmotion.range.range import RangeCalcCondition, RangeCalculator
+from linkmotion.range.range_cal import RangeCalcCondition, RangeCalculator
 
 
 @pytest.fixture
@@ -287,7 +287,7 @@ class TestRangeCalculator:
 
         names = calculator.get_axis_names()
 
-        assert names == []
+        assert names == ()
 
     def test_get_axis_names_with_axes(self, simple_robot):
         """Test get_axis_names with axes added."""
@@ -310,7 +310,7 @@ class TestRangeCalculator:
 
         points = calculator.get_axis_points()
 
-        assert points == []
+        assert points == ()
 
     def test_get_axis_points_with_axes(self, simple_robot):
         """Test get_axis_points with axes added."""
